.. webapi-error::
   :instance: reviewboard.webapi.errors.INVALID_CHANGE_NUMBER

   The change number specified when creating a review request could not be
   found in the repository. This is used for repositories that keep track of
   changeset information server-side, such as Perforce.
